@@ -5,7 +5,7 @@ use warnings;
 use utf8;
 use 5.014000;
 
-BEGIN { our $VERSION = 'v1.1.2'; }
+BEGIN { our $VERSION = 'v1.1.1'; }
 
 use Carp qw(croak);
 use Cwd qw(abs_path);
@@ -19,6 +19,7 @@ use Getopt::Long;
 use IO::File;
 use Log::Log4perl qw(:easy get_logger);
 use Perl::Tidy;
+use Pod::Usage;
 use TeX::Hyphen;
 use SVN::Client;
 use URI;
@@ -94,7 +95,7 @@ while (<DATA>) {
 }
 
 my $ctx = SVN::Client->new();
-my $rel = dirname( abs_path __FILE__ ) . $SLASH;
+my $rel = File::Basename::dirname( abs_path __FILE__ ) . $SLASH;
 
 my $dir = File::Temp->newdir();
 $log->debug( sprintf $LOG{'EXPORT'}, $REPO{'utf'}{'root'}, $dir->dirname );
@@ -112,7 +113,7 @@ foreach my $file (@files) {
     ## use critic
 }
 
-find( \&patterns, ( $dir->dirname ) );
+File::Find::find( \&patterns, ( $dir->dirname ) );
 
 sub patterns {
     ## no critic qw(ProhibitUnusedCapture)
@@ -127,7 +128,10 @@ sub patterns {
         $package = ucfirst $package;
         return if ( $package =~ /$CASE_CONFLICT/xmgs );
         my $filename = $package . $PM_EXT;
-        my $content  = read_file( $File::Find::name, 'binmode' => ':utf8' );
+## no critic qw(prohibitCallsToUnexportedSubs)
+        my $content =
+          File::Slurp::read_file( $File::Find::name, 'binmode' => ':utf8' );
+## use critic
 
         if ( my ($encoding) = $content =~ /$ENCODINGS/xmis ) {
             $encoding =~ s/($ISO)(\d)/$1$DASH$2/xmgis;
@@ -277,7 +281,7 @@ while (<DATA>) {
 	 $pattern_file .= $_;
 }
 
-sub data {
+sub pattern_data {
 	return $pattern_file;
 }
 
@@ -295,7 +299,7 @@ sub version {
 
 =over 4
 
-=item $pattern-E<gt>data();
+=item $pattern-E<gt>pattern_data();
 
 Returns the pattern data.
 
