@@ -17,7 +17,7 @@ use File::Slurp qw(read_file);
 use LWP::Simple qw(getstore);
 use Perl::Tidy;
 
-our $VERSION = v1.1.2;
+our $VERSION = v1.1.1;
 use Readonly;
 
 ## no critic qw(prohibitCallsToUnexportedSubs)
@@ -50,7 +50,9 @@ if (
   )
 {
     $zip = Archive::Zip->new();
-    if ( $zip->read($zip_name) != AZ_OK ) {
+## no critic qw(prohibitCallsToUnexportedSubs)
+    if ( $zip->read($zip_name) != Archive::Zip::AZ_OK ) {
+## use critic
         unlink $zip_name;
         ## no critic qw(RequireUseOfExceptions)
         croak 'read error';
@@ -94,7 +96,9 @@ my $filename;
 my $package;
 
 # Prepare to rewrite the MANIFEST including the generated files:
+## no critic qw(prohibitCallsToUnexportedSubs)
 my @files = File::Slurp::read_file( $MANIFEST, 'binmode' => ':utf8' );
+## use critic
 ## no critic qw(ProhibitCallsToUnexportedSubs RequireExplicitInclusion ProhibitCallsToUndeclaredSubs)
 my $manifest = IO::File->new(qq{> $MANIFEST});
 ## use critic
@@ -236,7 +240,7 @@ while (<DATA>) {
 	 $pattern_file .= $_;
 }
 
-sub data {
+sub pattern_data {
 	return $pattern_file;
 }
 
@@ -250,6 +254,20 @@ sub version {
 
 =head1 C<%s> hyphenation pattern class
 
+=head1 SUBROUTINES/METHODS
+
+=over 4
+
+=item $pattern-E<gt>pattern_data();
+
+Returns the pattern data.
+
+=item $pattern-E<gt>version();
+
+Returns the version of the pattern package.
+
+=back
+
 =head1 Copyright
 
 =begin text
